summaryrefslogtreecommitdiff
path: root/src/i_engine.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/i_engine.hpp')
-rw-r--r--src/i_engine.hpp9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/i_engine.hpp b/src/i_engine.hpp
index d64027d..81b56df 100644
--- a/src/i_engine.hpp
+++ b/src/i_engine.hpp
@@ -41,10 +41,11 @@ namespace zmq
// are messages to send available.
virtual void revive () = 0;
- // Start tracing the message route. Engine should add the identity
- // supplied to all inbound messages and trim identity from all the
- // outbound messages.
- virtual void traceroute (const blob_t &identity_) = 0;
+ // Engine should add the prefix supplied to all inbound messages.
+ virtual void add_prefix (const blob_t &identity_) = 0;
+
+ // Engine should trim prefix from all the outbound messages.
+ virtual void trim_prefix () = 0;
};
}